#line 1 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"
/* Include this first to avoid warnings about re-definitions on windows */
#include <stdint.h>

#line 5 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define osl_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer osl_create_buffer
#endif

#ifdef yy_delete_buffer
#define osl_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer osl_delete_buffer
#endif

#ifdef yy_scan_buffer
#define osl_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer osl_scan_buffer
#endif

#ifdef yy_scan_string
#define osl_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string osl_scan_string
#endif

#ifdef yy_scan_bytes
#define osl_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes osl_scan_bytes
#endif

#ifdef yy_init_buffer
#define osl_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer osl_init_buffer
#endif

#ifdef yy_flush_buffer
#define osl_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer osl_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define osl_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state osl_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define osl_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer osl_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define oslpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state oslpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define oslpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state oslpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define oslensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack oslensure_buffer_stack
#endif

#ifdef yylex
#define osllex_ALREADY_DEFINED
#else
#define yylex osllex
#endif

#ifdef yyrestart
#define oslrestart_ALREADY_DEFINED
#else
#define yyrestart oslrestart
#endif

#ifdef yylex_init
#define osllex_init_ALREADY_DEFINED
#else
#define yylex_init osllex_init
#endif

#ifdef yylex_init_extra
#define osllex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra osllex_init_extra
#endif

#ifdef yylex_destroy
#define osllex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy osllex_destroy
#endif

#ifdef yyget_debug
#define oslget_debug_ALREADY_DEFINED
#else
#define yyget_debug oslget_debug
#endif

#ifdef yyset_debug
#define oslset_debug_ALREADY_DEFINED
#else
#define yyset_debug oslset_debug
#endif

#ifdef yyget_extra
#define oslget_extra_ALREADY_DEFINED
#else
#define yyget_extra oslget_extra
#endif

#ifdef yyset_extra
#define oslset_extra_ALREADY_DEFINED
#else
#define yyset_extra oslset_extra
#endif

#ifdef yyget_in
#define oslget_in_ALREADY_DEFINED
#else
#define yyget_in oslget_in
#endif

#ifdef yyset_in
#define oslset_in_ALREADY_DEFINED
#else
#define yyset_in oslset_in
#endif

#ifdef yyget_out
#define oslget_out_ALREADY_DEFINED
#else
#define yyget_out oslget_out
#endif

#ifdef yyset_out
#define oslset_out_ALREADY_DEFINED
#else
#define yyset_out oslset_out
#endif

#ifdef yyget_leng
#define oslget_leng_ALREADY_DEFINED
#else
#define yyget_leng oslget_leng
#endif

#ifdef yyget_text
#define oslget_text_ALREADY_DEFINED
#else
#define yyget_text oslget_text
#endif

#ifdef yyget_lineno
#define oslget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno oslget_lineno
#endif

#ifdef yyset_lineno
#define oslset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno oslset_lineno
#endif

#ifdef yyget_column
#define oslget_column_ALREADY_DEFINED
#else
#define yyget_column oslget_column
#endif

#ifdef yyset_column
#define oslset_column_ALREADY_DEFINED
#else
#define yyset_column oslset_column
#endif

#ifdef yywrap
#define oslwrap_ALREADY_DEFINED
#else
#define yywrap oslwrap
#endif

#ifdef yyget_lval
#define oslget_lval_ALREADY_DEFINED
#else
#define yyget_lval oslget_lval
#endif

#ifdef yyset_lval
#define oslset_lval_ALREADY_DEFINED
#else
#define yyset_lval oslset_lval
#endif

#ifdef yyalloc
#define oslalloc_ALREADY_DEFINED
#else
#define yyalloc oslalloc
#endif

#ifdef yyrealloc
#define oslrealloc_ALREADY_DEFINED
#else
#define yyrealloc oslrealloc
#endif

#ifdef yyfree
#define oslfree_ALREADY_DEFINED
#else
#define yyfree oslfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define oslwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 64
#define YY_END_OF_BUFFER 65
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[299] =
    {   0,
        0,    0,   65,   63,   61,   60,   62,   63,   63,   63,
       63,   63,   63,   63,   35,   35,   63,   63,   63,   34,
       63,   63,   63,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   63,   61,   63,   61,   55,    0,   38,    0,   50,
       43,   41,   56,   39,   57,   40,   37,    0,   42,   37,
       35,    0,    0,   48,   52,   54,   53,   49,   34,   58,
       59,   45,   34,   34,   34,   34,   34,   34,   34,   34,
        7,   34,   34,   34,   34,   34,   34,   34,   11,   34,
       34,   34,   34,   34,   26,   34,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   44,   51,   61,    0,    0,    1,
        0,    0,    2,   37,    0,    0,   37,   36,   46,   47,
       27,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   10,   34,   34,   34,
       14,   34,   34,   34,   28,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,    0,   37,
        0,    0,   37,   29,   34,   34,   34,   34,   34,   34,
       34,   34,    8,   30,   34,   34,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   32,   34,   34,   34,
       34,   34,   34,   34,   24,   34,    0,   37,    3,   34,
        5,   34,   34,   34,   34,    9,   34,   34,   34,   34,
       34,   34,   18,   34,   34,   34,   34,   31,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   33,   34,   34,
       34,   34,   25,   34,   34,   34,   34,   15,   16,   17,
       34,   34,   19,   20,   21,   22,   34,   34,   34,   34,
       34,   23,   34,    4,   34,   34,   34,   34,   34,    6,
       34,   34,   34,   34,   34,   13,   12,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    8,    1,    1,
        1,    9,   10,    1,   11,   12,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   15,   15,    1,    1,   16,
       17,   18,    1,    1,   19,   19,   19,   19,   20,   19,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   22,   21,   21,
       23,   24,    1,   25,   26,    1,   27,   28,   29,   30,

       31,   32,   33,   34,   35,   21,   36,   37,   38,   39,
       40,   41,   21,   42,   43,   44,   45,   46,   47,   48,
       49,   50,    1,   51,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[52] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    1,    1,    1,    3,    3,
        4,    4,    1,    1,    1,    4,    3,    3,    3,    3,
        3,    3,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        1
    } ;

static const flex_int16_t yy_base[304] =
    {   0,
        0,   50,  398,  399,   51,  399,  380,   48,   48,  379,
       49,   47,   46,   50,   56,   65,   57,  378,   64,    0,
      371,  390,  375,  352,   44,   61,   52,   52,   66,   70,
      350,  362,  348,   52,   70,  356,   79,   85,  347,   90,
      351,   73,  129,  381,  116,  399,  105,  399,    0,  399,
      399,  399,  399,  399,  399,  399,  123,  380,  399,  125,
      132,  147,    0,  365,  399,  399,  399,  364,    0,  399,
      399,  399,  350,  339,  347,  334,  349,   35,  111,  343,
      329,  330,  327,  327,  333,  329,  326,  332,    0,  329,
       91,  326,  320,  107,    0,  319,  327,  120,  333,  316,

      319,   72,  126,  323,  319,  321,  310,  313,  124,  311,
      323,  309,  315,  314,  399,  399,  162,  345,  344,  399,
      160,  343,  399,  158,  166,  127,  168,    0,  399,  399,
        0,  308,  317,  312,  300,  298,  297,  299,  141,  311,
      309,  305,  297,  303,  290,  305,    0,  300,  285,  294,
        0,  295,  285,  288,    0,  284,  285,  277,  278,  284,
      275,  277,  279,  286,  272,  151,  271,  273,  270,  281,
      280,  147,  275,  260,  264,  263,  276,  268,  176,  178,
      184,  186,  188,    0,  268,  260,  257,  259,  256,  264,
      253,  260,    0,    0,  254,  264,  250,  254,  254,  252,

      255,  262,  243,  243,  259,  254,  249,  241,  238,  250,
      240,  244,  239,  248,  247,  238,    0,  244,  233,  233,
      238,  235,  229,  223,    0,  236,  190,  192,    0,  224,
        0,  226,  227,  232,  223,    0,  231,  225,  228,  210,
      220,  212,    0,  211,  225,  224,  213,    0,  221,  218,
      220,  215,  203,  212,  218,  213,  201,    0,  203,  202,
      198,  212,    0,  207,  192,  192,  196,    0,    0,    0,
      203,  189,    0,    0,    0,    0,  188,  199,  192,  198,
      195,    0,  178,    0,  181,  184,  179,  178,  167,    0,
      169,  158,  136,  101,   68,    0,    0,  399,  213,  215,

      219,  223,   66
    } ;

static const flex_int16_t yy_def[304] =
    {   0,
      298,    1,  298,  298,  298,  298,  298,  299,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  300,
      298,  298,  298,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  298,  298,  301,  298,  298,  299,  298,  299,  298,
      298,  298,  298,  298,  298,  298,  298,  302,  298,  298,
      298,  298,  303,  298,  298,  298,  298,  298,  300,  298,
      298,  298,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  298,  298,  298,  301,  301,  298,
      298,  302,  298,  298,  298,  298,  298,  303,  298,  298,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  298,  298,
      298,  298,  298,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  298,  298,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,    0,  298,  298,

      298,  298,  298
    } ;

static const flex_int16_t yy_nxt[451] =
    {   0,
        4,    5,    6,    5,    7,    8,    4,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   21,   22,   23,   20,   24,   25,   26,   27,
       28,   29,   20,   20,   30,   20,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   20,   20,   20,
       42,   43,   45,   48,   45,   50,   44,   55,   53,   57,
       57,  136,   58,   56,   51,   54,   59,   60,  128,   61,
       61,   49,   64,   65,  137,   62,   60,   63,   61,   61,
       67,   68,   80,   74,   62,   75,   62,   76,   82,  115,
       83,   81,   85,   95,   77,   62,   96,   78,  297,   84,

       79,   89,   86,   63,  163,   87,   90,   88,   91,   97,
       48,   98,  101,  102,   99,  105,  110,   45,  106,   45,
      111,  164,  103,  116,  112,  104,  107,  150,   49,  113,
      117,  296,   45,  108,  151,  118,   57,   57,  124,  124,
      127,  127,  121,   60,  125,   61,   61,  138,  154,  139,
      155,   62,  165,  121,  158,  125,  126,  126,  172,  159,
      127,  127,   62,  117,  295,   45,  173,  166,  118,  179,
      179,  124,  124,  180,  180,  182,  182,  181,  219,  183,
      183,  127,  127,  189,  190,  213,  220,  248,  181,  180,
      180,  180,  180,  227,  227,  214,  258,  228,  228,  183,

      183,  183,  183,  228,  228,  228,  228,  293,  217,  292,
      291,  290,  294,   47,  258,   47,   47,   69,   69,  119,
      119,  119,  119,  122,  122,  122,  122,  258,  289,  217,
      217,  288,  287,  194,  286,  184,  285,  284,  283,  282,
      281,  280,  279,  278,  277,  217,  276,  275,  248,  248,
      248,  274,  273,  272,  271,  270,  269,  268,  194,  267,
      194,  194,  184,  266,  265,  264,  263,  262,  261,  260,
      259,  258,  257,  256,  255,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  245,  244,  243,  242,  241,  240,
      239,  238,  237,  236,  194,  235,  234,  233,  232,  184,

      231,  230,  184,  229,  226,  225,  224,  223,  222,  221,
      218,  217,  217,  216,  215,  212,  211,  210,  209,  208,
      207,  206,  205,  204,  203,  202,  201,  194,  200,  199,
      198,  197,  196,  195,  194,  193,  192,  191,  188,  187,
      186,  184,  184,  185,  184,  123,  120,  120,  178,  177,
      176,  175,  174,  171,  170,  169,  168,  167,  162,  161,
      160,  157,  156,  153,  152,  149,  148,  147,  146,  145,
      144,  143,  142,  141,  140,  135,  134,  133,  132,  131,
      130,  129,  123,  120,  114,  109,  100,   94,   93,   92,
       73,   72,   71,   70,   66,   52,   46,  298,    3,  298,

      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298
    } ;

static const flex_int16_t yy_chk[451] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    8,    5,    9,    2,   12,   11,   13,
       13,   78,   14,   12,    9,   11,   14,   15,  303,   15,
       15,    8,   17,   17,   78,   15,   16,   15,   16,   16,
       19,   19,   27,   25,   16,   25,   15,   26,   28,   42,
       28,   27,   29,   34,   26,   16,   34,   26,  295,   28,

       26,   30,   29,   15,  102,   29,   30,   29,   30,   35,
       47,   35,   37,   37,   35,   38,   40,   45,   38,   45,
       40,  102,   37,   42,   40,   37,   38,   91,   47,   40,
       43,  294,   43,   38,   91,   43,   57,   57,   60,   60,
      126,  126,   57,   61,   60,   61,   61,   79,   94,   79,
       94,   61,  103,   57,   98,   60,   62,   62,  109,   98,
       62,   62,   61,  117,  293,  117,  109,  103,  117,  121,
      121,  124,  124,  121,  121,  125,  125,  124,  172,  125,
      125,  127,  127,  139,  139,  166,  172,  292,  124,  179,
      179,  180,  180,  181,  181,  166,  289,  181,  181,  182,

      182,  183,  183,  227,  227,  228,  228,  291,  288,  287,
      286,  285,  291,  299,  283,  299,  299,  300,  300,  301,
      301,  301,  301,  302,  302,  302,  302,  281,  280,  279,
      278,  277,  272,  271,  267,  266,  265,  264,  262,  261,
      260,  259,  257,  256,  255,  254,  253,  252,  251,  250,
      249,  247,  246,  245,  244,  242,  241,  240,  239,  238,
      237,  235,  234,  233,  232,  230,  226,  224,  223,  222,
      221,  220,  219,  218,  216,  215,  214,  213,  212,  211,
      210,  209,  208,  207,  206,  205,  204,  203,  202,  201,
      200,  199,  198,  197,  196,  195,  192,  191,  190,  189,

      188,  187,  186,  185,  178,  177,  176,  175,  174,  173,
      171,  170,  169,  168,  167,  165,  164,  163,  162,  161,
      160,  159,  158,  157,  156,  154,  153,  152,  150,  149,
      148,  146,  145,  144,  143,  142,  141,  140,  138,  137,
      136,  135,  134,  133,  132,  122,  119,  118,  114,  113,
      112,  111,  110,  108,  107,  106,  105,  104,  101,  100,
       99,   97,   96,   93,   92,   90,   88,   87,   86,   85,
       84,   83,   82,   81,   80,   77,   76,   75,   74,   73,
       68,   64,   58,   44,   41,   39,   36,   33,   32,   31,
       24,   23,   22,   21,   18,   10,    7,    3,  298,  298,

      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  298
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
/* Copyright Contributors to the Open Shading Language project.
 * SPDX-License-Identifier: BSD-3-Clause
 * https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
 */
/** Lexical scanner for Open Shading Language
 **/

/************************************************************
 * Definitions section
 ************************************************************/
/* Option 'noyywrap' indicates that when EOF is hit, yyin does not
 * automatically reset to another file.
 */
#define YY_NO_INPUT 1
/* never-interactive fixes a Windows compatibility problem where the
 * lexer emits isatty calls that don't exist.
 */
#line 34 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
 /* Option 'prefix' creates a C++ lexer with the given prefix, so that
  * we can link with other flex-generated lexers in the same application
  * without name conflicts.
  */
 /* Define regular expression macros
  ************************************************/
 /* white space, not counting newline */
 /* alpha character */
 /* numerals */
 /* Integer literal */
 /* floating point literal (E, FLT1, FLT2, FLT3 are just helpers)
  * NB: we don't allow leading +/- due to ambiguity between
  * whether "a-0.5" is really "a -0.5" or "a - 0.5".  Resolve this
  * in the grammar.
  */
 /* string literal */
        /* " This extra quote fixes emacs syntax highlighting on this file */
 /* Identifier: alphanumeric, may contain digits after the first character */
 /* C preprocessor (cpp) directives */
 /* Note for lex newbies: the following '%{ .. %}' section contains literal
  * C code that will be inserted at the top of code that flex generates.
  */
#include <climits>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <vector>
#include <string>

#include <OpenImageIO/thread.h>
#include <OpenImageIO/strutil.h>
#include "oslcomp_pvt.h"

using namespace OSL;
using namespace OSL::pvt;

#include "oslgram.hpp"   /* Generated by bison/yacc */


#ifdef _WIN32
#define YY_NO_UNISTD_H

#ifdef _MSC_VER
#define strtoll _strtoi64
#include <io.h>
#define isatty _isatty
#endif
#endif

// flex itself will generate fatal warnings about signed vs unsigned.
// Bypass that nonsense.
OSL_GCC_ONLY_PRAGMA(GCC diagnostic ignored "-Wsign-compare")

// flex uses the 'register' keyword, warned because it's deprecated in C++17.
OSL_CLANG_PRAGMA(GCC diagnostic ignored "-Wdeprecated-register")
OSL_CLANG_PRAGMA(GCC diagnostic ignored "-Wregister")
OSL_GCC_ONLY_PRAGMA(GCC diagnostic ignored "-Wregister")

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC visibility push(hidden)
#endif

OSL_NAMESPACE_BEGIN
namespace pvt {
    void preprocess (const char *str, OSLCompilerImpl* oslcompiler, YYLTYPE* yyloc_param);
    int osllex(YYSTYPE* yylval_param, YYLTYPE* yyloc_param, void* yyscanner, OSLCompilerImpl* oslcompiler);
}
OSL_NAMESPACE_END
#define YY_DECL int OSL::pvt::osllex(YYSTYPE* yylval_param, YYLTYPE* yyloc_param, void* yyscanner, OSLCompilerImpl* oslcompiler)

// Macro that sets the yylloc line variables to the current parse line.
#define SETLINE yyloc_param->first_line = yyloc_param->last_line = oslcompiler->lineno()

#line 935 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"
#line 936 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE OSL::pvt::OSLCompilerImpl *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 130 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"


#line 133 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
 /************************************************
  * Lexical matching rules
  ************************************************/

 /* preprocessor symbols */
#line 1218 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 299 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 298 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 138 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  OSL::pvt::preprocess (yytext, oslcompiler, yyloc_param); SETLINE; }
	YY_BREAK
/* Comments */
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 141 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  oslcompiler->incr_lineno(); /* skip it */
                           SETLINE;
                        }
	YY_BREAK
/* keywords */
case 3:
YY_RULE_SETUP
#line 146 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=BREAK); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 147 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=CLOSURE); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 148 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=COLORTYPE); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 149 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=CONTINUE); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 150 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=DO); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 151 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=ELSE); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 152 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=FLOATTYPE); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 153 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=FOR); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 154 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=IF_TOKEN); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 155 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=ILLUMINANCE); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 156 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=ILLUMINATE); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 157 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=INTTYPE); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 158 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=MATRIXTYPE); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 159 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=NORMALTYPE); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 160 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=OUTPUT); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 161 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=POINTTYPE); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 162 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=PUBLIC); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 163 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=RETURN); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 164 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=STRINGTYPE); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 165 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=STRUCT); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 166 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=VECTORTYPE); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 167 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=VOIDTYPE); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 168 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=WHILE); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 169 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=OR_OP); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 170 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=AND_OP); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 171 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=NOT_OP); }
	YY_BREAK
/* reserved words */
case 29:
#line 175 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
case 30:
#line 176 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
case 31:
#line 177 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
case 32:
#line 178 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
case 33:
YY_RULE_SETUP
#line 178 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            oslcompiler->errorfmt(oslcompiler->filename(),
                                                  oslcompiler->lineno(),
                                                  "'{}' is a reserved word",
                                                  yytext);
                            SETLINE;
                            return (yylval->i=RESERVED);
                        }
	YY_BREAK
/* Identifiers */
case 34:
YY_RULE_SETUP
#line 189 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            yylval->s = ustring(yytext).c_str();
                            SETLINE;
                            return IDENTIFIER;
                        }
	YY_BREAK
/* Literal values */
case 35:
YY_RULE_SETUP
#line 196 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            long long llval = strtoll (yytext, (char**)NULL, 10);
                            // we do not detect overflow when the value is INT_MAX+1,
                            // because negation happens later and -(INT_MAX+1) == INT_MIN
                            if (llval > ((long long)INT_MAX)+1) {
                                oslcompiler->errorfmt(oslcompiler->filename(),
                                                      oslcompiler->lineno(),
                                                      "integer overflow, value must be between {} and {}.",
                                                      INT_MIN, INT_MAX);
                            }
                            yylval->i = (int)llval;
                            SETLINE;
                            return INT_LITERAL;
                        }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 210 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            long long llval = strtoll (yytext, (char**)NULL, 16);
                            // we do not detect overflow when the value is INT_MAX+1,
                            // because negation happens later and -(INT_MAX+1) == INT_MIN
                            if (llval > ((long long)UINT_MAX)+1) {
                                oslcompiler->errorfmt(oslcompiler->filename(),
                                                      oslcompiler->lineno(),
                                                      "integer overflow, value must be between {} and {}.",
                                                      INT_MIN, INT_MAX);
                            }
                            yylval->i = (int)llval;
                            SETLINE;
                            return INT_LITERAL;
                        }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 227 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            yylval->f = OIIO::Strutil::from_string<float>(yytext);
                            SETLINE;
                            return FLOAT_LITERAL;
                        }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 233 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{
                            // grab the material between the quotes
                            string_view s(yytext + 1, yyleng - 2);
                            std::string unescaped;
                            if (s.find('\\') != string_view::npos) {
                                // Only make a new string if we must unescape
                                unescaped = OIIO::Strutil::unescape_chars(s);
                                s = string_view(unescaped);
                            }
                            yylval->s = ustring(s).c_str();
                            SETLINE;
                            // std::cerr << "osllex string '" << yylval->s << "'\n";
                            return STRING_LITERAL;
                        }
	YY_BREAK
/* The one-char operators (like "+") will return correctly with the
  * catch-all rule, but we need to define the two-character operators
  * so they are not lexed as '+' and '=' separately, for example.
  */
case 39:
YY_RULE_SETUP
#line 252 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=ADD_ASSIGN); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 253 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=SUB_ASSIGN); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 254 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=MUL_ASSIGN); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 255 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=DIV_ASSIGN); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 256 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=BIT_AND_ASSIGN); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 257 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=BIT_OR_ASSIGN); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 258 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=XOR_ASSIGN); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 259 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=SHL_ASSIGN); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 260 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=SHR_ASSIGN); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 261 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=SHL_OP); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 262 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=SHR_OP); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 263 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=AND_OP); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 264 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=OR_OP); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 265 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=LE_OP); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 266 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=GE_OP); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 267 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=EQ_OP); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 268 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=NE_OP); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 269 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=INCREMENT); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 270 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=DECREMENT); }
	YY_BREAK
/* Beginning of metadata */
case 58:
YY_RULE_SETUP
#line 273 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i=METADATA_BEGIN); }
	YY_BREAK
/* End of line */
case 59:
/* rule 59 can match eol */
#line 277 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 277 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  oslcompiler->incr_lineno();
                           SETLINE;
                        }
	YY_BREAK
/* Ignore whitespace */
case 61:
YY_RULE_SETUP
#line 282 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  }
	YY_BREAK
/* catch-all rule for any other single characters */
case 62:
YY_RULE_SETUP
#line 285 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i = NOT_OP); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 286 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
{  SETLINE;  return (yylval->i = *yytext); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 288 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"
ECHO;
	YY_BREAK
#line 1652 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/build/src/liboslcomp/osllex.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 299 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 299 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 298);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 288 "/build/openshadinglanguage/src/OpenShadingLanguage-1.15.3.0/src/liboslcomp/osllex.l"


OSL_NAMESPACE_BEGIN
namespace pvt {   // OSL::pvt

void
preprocess (const char *str, OSLCompilerImpl* oslcompiler, YYLTYPE* yyloc_param)
{
#if 0
    printf ("preprocess: <%s>\n", str);
#endif
    const char *p = str;
    while (*p == ' ' || *p == '\t')
        p++;
    if (*p != '#') {
        oslcompiler->errorfmt(oslcompiler->filename(), oslcompiler->lineno(),
                              "Possible bug in shader preprocess");
        SETLINE;
        return;
    }
    p++;
    while (*p == ' ' || *p == '\t')
        p++;
    if (! strncmp (p, "pragma", 6)) {
        // pragma
        OIIO::string_view line (p+6);
        string_view pragmatype = OIIO::Strutil::parse_word (line);
        if (pragmatype == "error") {
            string_view msg;
            if (OIIO::Strutil::parse_string(line, msg))
                oslcompiler->errorfmt(oslcompiler->filename(),
                                      oslcompiler->lineno(), "{}", msg);
            else
                oslcompiler->errorfmt(oslcompiler->filename(),
                                      oslcompiler->lineno(),
                                      "<unknown error>");
        }
        else if (pragmatype == "warning") {
            string_view msg;
            if (OIIO::Strutil::parse_string(line, msg))
                oslcompiler->warningfmt(oslcompiler->filename(),
                                      oslcompiler->lineno(), "{}", msg);
            else
                oslcompiler->warningfmt(oslcompiler->filename(),
                                        oslcompiler->lineno(),
                                        "<unknown warning>");
        }
        else if (OIIO::Strutil::iequals (pragmatype, "osl")) {
            string_view pragmaname = OIIO::Strutil::parse_word (line);
            if (pragmaname == "nowarn") {
                oslcompiler->pragma_nowarn ();
            } else {
                oslcompiler->warningfmt(oslcompiler->filename(), oslcompiler->lineno(),
                                        "Unknown pragma '{}'", pragmaname);
            }
        }
        // N.B. Any other pragmas that don't start with "osl" are ignored
        oslcompiler->incr_lineno();  // the pragma ends with an EOLN
    } else {  /* probably the line number and filename */
        if (! strncmp (p, "line", 4))
            p += 4;
        int line = atoi (p);
        if (line > 0) {
            const char *f = strchr (str, '\"'); // " undo syntax highlight
            if (f) {
                ++f;  // increment to past the quote
                int len = 0;  // count of chars within quotes
                while (f[len] && f[len] != '\"') // " undo syntax highlight
                    ++len;
                std::string filename (f, len);
                // Make it relative to the working directory, so error output
                // isn't hugely cluttered (and also to make the preprocessor's
                // error output match the standard cpp.
                if (filename.find (oslcompiler->cwd()) == 0) {
                    filename.erase (0, oslcompiler->cwd().size());
                    if (filename.size() &&
                        (filename[0] == '/' || filename[0] == '\\'))
                        filename.erase (0, 1);
                }
                ustring ufilename(filename);
                oslcompiler->filename (ufilename);
                // TODO: We no longer use Boost Wave, so verify if the
                // workaround below is still needed ..
                // Spooky workaround for Boost Wave bug: force_include
                // is broken and doesn't give us the right lines/files, so
                // instead we forcefully insert a '#include "stdosl.h"' into
                // the stream ourselves, but this in turn makes the rest
                // of the main file all have line counts one line off!
                // So we fix it here, ugh.
                if (ufilename == oslcompiler->main_filename())
                    --line;
            }
            oslcompiler->lineno (line);
        } else {
            oslcompiler->errorfmt(oslcompiler->filename(), oslcompiler->lineno(),
                                  "Unrecognized preprocessor command: #{}", p);
        }
    }
    SETLINE;
}

static std::mutex oslcompiler_mutex;

bool
OSLCompilerImpl::osl_parse_buffer (const std::string &preprocessed_buffer)
{
    // Thread safety with the lexer/parser
    std::lock_guard<std::mutex> lock(oslcompiler_mutex);

    yyscan_t scanner;
    yylex_init(&scanner);
    YY_BUFFER_STATE buffer = yy_scan_string(preprocessed_buffer.c_str(), scanner);
    yy_switch_to_buffer (buffer, scanner);
    oslparse (scanner, this);
    bool parseerr = error_encountered();
    yy_delete_buffer (buffer, scanner);
    yylex_destroy(scanner);

    return parseerr;
}

}; // namespace pvt
OSL_NAMESPACE_END

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC visibility pop
#endif

